'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _regenerator;

function _load_regenerator() {
  return _regenerator = _interopRequireDefault(require('babel-runtime/regenerator'));
}

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _uuid;

function _load_uuid() {
  return _uuid = _interopRequireDefault(require('uuid'));
}

var _fsExtra;

function _load_fsExtra() {
  return _fsExtra = _interopRequireDefault(require('fs-extra'));
}

var _path;

function _load_path() {
  return _path = _interopRequireDefault(require('path'));
}

var _ramda;

function _load_ramda() {
  return _ramda = _interopRequireDefault(require('ramda'));
}

var _npmClient;

function _load_npmClient() {
  return _npmClient = _interopRequireDefault(require('../npm-client'));
}

var _scope;

function _load_scope() {
  return _scope = require('../scope');
}

var _bitId;

function _load_bitId() {
  return _bitId = require('../bit-id');
}

var _constants;

function _load_constants() {
  return _constants = require('../constants');
}

var _utils;

function _load_utils() {
  return _utils = require('../utils');
}

var _logger;

function _load_logger() {
  return _logger = _interopRequireDefault(require('../logger/logger'));
}

var _consumer;

function _load_consumer() {
  return _consumer = require('../consumer');
}

var _component;

function _load_component() {
  return _component = _interopRequireDefault(require('../consumer/component'));
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Environment = function () {
  function Environment(scope, ciDir) {
    _classCallCheck(this, Environment);

    this.scope = scope;
    this.path = ciDir || (_path || _load_path()).default.join(scope.getPath(), (_constants || _load_constants()).ISOLATED_ENV_ROOT, (0, (_uuid || _load_uuid()).default)());
    (_logger || _load_logger()).default.debug(`creating a new isolated environment at ${this.path}`);
  }

  _createClass(Environment, [{
    key: 'create',
    value: function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/(_regenerator || _load_regenerator()).default.mark(function _callee() {
        return (_regenerator || _load_regenerator()).default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return (0, (_utils || _load_utils()).mkdirp)(this.path);

              case 2:
                _context.next = 4;
                return (_consumer || _load_consumer()).Consumer.createWithExistingScope(this.path, this.scope);

              case 4:
                this.consumer = _context.sent;

              case 5:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function create() {
        return _ref.apply(this, arguments);
      }

      return create;
    }()
  }, {
    key: 'installNpmPackages',
    value: function installNpmPackages(components, verbose) {
      return Promise.all(components.map(function (component) {
        if ((_ramda || _load_ramda()).default.isEmpty(component.packageDependencies)) return Promise.resolve();
        return (_npmClient || _load_npmClient()).default.install(component.packageDependencies, { cwd: component.writtenPath }, verbose);
      }));
    }

    /**
     * import a component end to end. Including importing the dependencies and installing the npm
     * packages.
     *
     * @param rawId
     * @return {Promise.<Component>}
     */

  }, {
    key: 'importE2E',
    value: function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/(_regenerator || _load_regenerator()).default.mark(function _callee2(rawId, verbose) {
        var installDependencies = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
        var writePath = arguments[3];
        var writeBitDependencies = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
        var createNpmLinkFiles = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
        var bitId, componentDependenciesArr, componentWithDependencies, componentWithDependenciesFlatten;
        return (_regenerator || _load_regenerator()).default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                bitId = (_bitId || _load_bitId()).BitId.parse(rawId);
                _context2.next = 3;
                return this.scope.getMany([bitId]);

              case 3:
                componentDependenciesArr = _context2.sent;
                _context2.next = 6;
                return this.consumer.writeToComponentsDir({
                  componentsWithDependencies: componentDependenciesArr,
                  writeToPath: writePath,
                  writeBitDependencies,
                  createNpmLinkFiles
                });

              case 6:
                componentWithDependencies = (_ramda || _load_ramda()).default.head(componentDependenciesArr);
                componentWithDependenciesFlatten = [componentWithDependencies.component].concat(_toConsumableArray(componentWithDependencies.dependencies));

                if (!installDependencies) {
                  _context2.next = 11;
                  break;
                }

                _context2.next = 11;
                return this.installNpmPackages(componentWithDependenciesFlatten, verbose);

              case 11:
                return _context2.abrupt('return', componentWithDependencies);

              case 12:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function importE2E(_x4, _x5) {
        return _ref2.apply(this, arguments);
      }

      return importE2E;
    }()
  }, {
    key: 'getPath',
    value: function getPath() {
      return this.path;
    }
  }, {
    key: 'destroy',
    value: function destroy() {
      var _this = this;

      return new Promise(function (resolve, reject) {
        (_fsExtra || _load_fsExtra()).default.remove(_this.path, function (err) {
          if (err) return reject(err);
          (_logger || _load_logger()).default.debug(`destroying the isolated environment at ${_this.path}`);
          return resolve();
        });
      });
    }
  }]);

  return Environment;
}();

exports.default = Environment;
//# sourceMappingURL=environment_REMOTE_1463.js.map